==> ejc-wzxt-api-3.0.0-20201015.082918-49-sources.jar: com/ejianc/business/wzxt/vo/CheckDetailRestVO.java <==
package com.ejianc.business.wzxt.vo;

/**
 * 验收明细表
 * 
 * @author generator
 * 
 */
public class CheckDetailRestVO {
    private static final long serialVersionUID = 1L;

    private Long id; // 主键ID
    private Long checkId; // 验收主键ID
    private Long materialId; // 物资主键
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String unit; // 单位
    private String spec; // 规格型号
    private java.math.BigDecimal checkNumsSum; // 验收数量
    private String materialManufacturer; // 生产厂家
    private String memo; // 备注

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    /**
     * 验收主键ID
     */
    public Long getCheckId() {
        return checkId;
    }

    /**
     * 验收主键ID
     */
    public void setCheckId(Long checkId) {
        this.checkId = checkId;
    }
    /**
     * 物资主键
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(String spec) {
        this.spec = spec;
    }
    /**
     * 验收数量
     */
    public java.math.BigDecimal getCheckNumsSum() {
        return checkNumsSum;
    }

    /**
     * 验收数量
     */
    public void setCheckNumsSum(java.math.BigDecimal checkNumsSum) {
        this.checkNumsSum = checkNumsSum;
    }
    /**
     * 生产厂家
     */
    public String getMaterialManufacturer() {
        return materialManufacturer;
    }

    /**
     * 生产厂家
     */
    public void setMaterialManufacturer(String materialManufacturer) {
        this.materialManufacturer = materialManufacturer;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }

}

==> ejc-wzxt-api-3.0.0-20210107.082815-97-sources.jar: com/ejianc/business/wzxt/vo/CheckDetailRestVO.java <==
package com.ejianc.business.wzxt.vo;

/**
 * 验收明细表
 * 
 * @author generator
 * 
 */
public class CheckDetailRestVO {
    private static final long serialVersionUID = 1L;

    private Long id; // 主键ID
    private Long checkId; // 验收主键ID
    private Long materialId; // 物资主键
    private String materialSourceId; // 物资来源主键
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeSourceId; // 物资类别来源主键
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String unit; // 单位
    private String spec; // 规格型号
    private java.math.BigDecimal checkNumsSum; // 验收数量
    private String materialManufacturer; // 生产厂家
    private String memo; // 备注

    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }

    public String getMaterialTypeSourceId() {
        return materialTypeSourceId;
    }

    public void setMaterialTypeSourceId(String materialTypeSourceId) {
        this.materialTypeSourceId = materialTypeSourceId;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    /**
     * 验收主键ID
     */
    public Long getCheckId() {
        return checkId;
    }

    /**
     * 验收主键ID
     */
    public void setCheckId(Long checkId) {
        this.checkId = checkId;
    }
    /**
     * 物资主键
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(String spec) {
        this.spec = spec;
    }
    /**
     * 验收数量
     */
    public java.math.BigDecimal getCheckNumsSum() {
        return checkNumsSum;
    }

    /**
     * 验收数量
     */
    public void setCheckNumsSum(java.math.BigDecimal checkNumsSum) {
        this.checkNumsSum = checkNumsSum;
    }
    /**
     * 生产厂家
     */
    public String getMaterialManufacturer() {
        return materialManufacturer;
    }

    /**
     * 生产厂家
     */
    public void setMaterialManufacturer(String materialManufacturer) {
        this.materialManufacturer = materialManufacturer;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }

}
